import Button from '../sensors/Button';
import Potentiometer from '../sensors/Potentiometer';
import RotaryEncoder from '../sensors/RotaryEncoder';
import Ultrasonic from '../sensors/Ultrasonic';
import Joystick from '../sensors/Joystick';

const registeredSensors = [
	Button,
	Potentiometer,
	RotaryEncoder,
	Ultrasonic,
	Joystick,
];

/**
 * # p5Adapter
 * 
 * ```
 * ```
 * 
 */
class P5Adapter 
{	
	sensorsByPinNum = {};

	constructor() 
	{
		Arduino.on('readPins', (event) => {
			for (let pinNum in event.pins) {
				this.sensorsByPinNum[pinNum]?.onChange( event, event.pins[pinNum] );
			}
		});
	}

	connectSensor( args = [] ) 
	{
		let type = args.shift();
		let classRef = registeredSensors.find( cl => cl.type == type );
		let sensor = new (classRef)( args );
		if (sensor.pinNum) {
			this.sensorsByPinNum[sensor.pinNum] = sensor;
		}
		return sensor;
	}
}


// create a Singleton...
const p5adapter = new P5Adapter();

// expose `connectSensor()` it as a global function, just like `createSlider()` in p5.js
window.connectSensor = function () {
	return p5adapter.connectSensor( Array.from(arguments) );
}

// expose the sensor types as globals constants
registeredSensors.forEach(( classRef ) => {
	window[classRef.name] = classRef.type;
});


import p5 from 'p5/lib/p5';

const sketch = window; // for single sketch
window.p5 = p5;

export {p5, sketch, p5adapter}


