
/**
 * # AbstractSensor
 * 
 */
export default class AbstractSensor 
{
	constructor( args ) 
	{
		this.pinNum = 0;
		this.pinData = {val:0};
		this.eventListeners = {};

		if (this.init) {
			this.init.apply( this, args );
		}
	}
	
	init( pin ) 
	{
		this.pinNum = pin;
		Arduino.cmd( {addSensor:{pin:pin, type:this.constructor.type}} );
	}

	onChange( event, pinData ) 
	{
		this.pinData = pinData;
	}

	value() 
	{
		return this.pinData?.val || 0;
	}

	addEventListener( event, callback ) 
	{
		if (!this.eventListeners[event]) {
			this.eventListeners[event] = {};
		}
		this.eventListeners[event][callback] = callback;
	}
	removeEventListener( event, callback ) 
	{
		delete(this.eventListeners[event]?.[callback]);
	}
	emitEvent( event, args = null ) 
	{
		if (args == null) args = this.pinData;
		if (!this.eventListeners[event]) return;
		for (let n in this.eventListeners[event]) {
			this.eventListeners[event][n]( args );
		}
	}
}
