import AbstractSensor from './AbstractSensor';

/**
 * # Joystick
 */
export default class Joystick extends AbstractSensor 
{
	static type = 90;
	static name = 'SENSOR_JOYSTICK';

    init( pins, minVal = 0, maxVal = 1024 ) 
    {
        let m = (maxVal - minVal)/2;
        this.pinNum = pins.vrx || pins.pin;
        this.pinData = {x:m, y:m, pressed:0};
        this.minVal = minVal;
        this.maxVal = maxVal;
        this.isPressed = false;

        Arduino.cmd( {addSensor:{
			pin: this.pinNum, 
			vry: pins.vry, 
			sw: pins.sw, 
			type: this.constructor.type
		}} );
    }

    pressed( callback ) 
	{
		this.addEventListener( 'pressed', callback );
	}
	
	released( callback ) 
	{
		this.addEventListener( 'released', callback );
	}

	onChange( event, pinData ) 
	{
		super.onChange( event, pinData );

		let val = this.pinData.pressed;
		if (val && !this.isPressed) {
			this.emitEvent( 'pressed' );
		}
		if (!val && this.isPressed) {
			this.emitEvent( 'released' );
		}
		this.isPressed = val;
	}

    valueX() {
        return this.minVal + this.pinData.x/1024 * (this.maxVal - this.minVal);
    }    
    valueY() {
        return this.minVal + this.pinData.y/1024 * (this.maxVal - this.minVal);
    }
}