import AbstractSensor from './AbstractSensor';

/**
 * # RotaryEncoder
 * 
 */
export default class RotaryEncoder extends AbstractSensor 
{
	static type = 30;
	static name = 'SENSOR_ROTARY_ENCODER';

	init( pins, minVal = null, maxVal = null, startVal = 0 ) 
	{
		this.pinNum = pins.clk || pins.pin;
		this.minVal = minVal;
		this.maxVal = maxVal;
		this.startVal = startVal;
		this.offsetVal = 0;
		this.pinData = {val:0};

		Arduino.cmd( {addSensor:{
			pin: this.pinNum, 
			dt: pins.dt, 
			sw: pins.sw, 
			type: this.constructor.type
		}} );
	}

	onChange( event, pinData ) 
	{
		super.onChange( event, pinData );
		let val = pinData.val + this.startVal - this.offsetVal;
		if (this.maxVal !== null && val > this.maxVal) {
			this.offsetVal = pinData.val + this.startVal - this.maxVal;
		} else if (this.minVal !== null && val < this.minVal) {
			this.offsetVal = pinData.val + this.startVal - this.minVal;
		}
	}

	value() {
		return this.pinData.val + this.startVal - this.offsetVal;
	}
}